@@ -50,9 +50,14 @@ class Runtime:
     @staticmethod
     def deserialize(data: bytes, c):
         node = c()
-        obj = json.loads(data, object_hook=lambda d: Namespace(**d))
-        for key in obj.__dict__.keys():
-            node.__setattr__(key, obj.__dict__[key])
+        obj = json.loads(data)
+        for key in obj.keys():
+            if key in node.__dict__.keys():
+                if type(obj[key]) is dict:
+                    node.__dict__[key] = type(node.__dict__[key])(**obj[key])
+                else:
+                    node.__dict__[key] = obj[key]
+
         return node
 
     @staticmethod
@@ -105,7 +110,15 @@ class Runtime:
         var = plugin_pb2.Variable(scope=scope, name=name)
         request = plugin_pb2.SetVariableRequest(variable=var, value=val)
         Runtime.client.SetVariable(request)
-		
+
+    @staticmethod
+    def get_vault_item(cred):
+        if Runtime.client is None:
+            return {}
+
+        request = plugin_pb2.GetVaultItemRequest(vaultId=cred.vaultId, ItemId=cred.itemId)
+        response = Runtime.client.GetVaultItem(request)
+        return json_format.MessageToDict(response.item)['value']
 		
     class _DefVal:
         def __init__(self, default: object):
