@@ -7,6 +7,16 @@ import json
 from enum import IntEnum
 
 
+class ECategory(IntEnum):
+    Null = 0,
+    Login = 1
+    Email = 2
+    CreditCard = 3
+    Token = 4
+    Database = 5
+    Document = 6
+    
+
 class _DefVal:
     def __init__(self, default: object):
         self.default = default
@@ -86,7 +96,7 @@ class Variable:
         return self.__hidden
 
     @property
-    def __input(self) -> bool:
+    def input(self) -> bool:
         return self.__isinput
 
     @property
@@ -104,6 +114,10 @@ class Variable:
     @property
     def enum(self) -> _Enum:
         return self.__enum
+        
+    @property
+    def category(self) -> ECategory:
+        return ECategory.Null
 
 
 class InVariable(Variable):
@@ -121,16 +135,6 @@ class OptVariable(Variable):
         return Runtime.get_variable(self, ctx)
 
 
-class ECategory(IntEnum):
-    Null = 0,
-    Login = 1
-    Email = 2
-    CreditCard = 3
-    Token = 4
-    Database = 5
-    Document = 6
-
-
 class Credentials:
     def __init__(self, vaultId: str='', itemId: str='', title: str='', category: ECategory=ECategory.Null):
         self.__vaultId = vaultId
